@@ -29,9 +29,10 @@ from .webrisk import (
     RiceDeltaEncoding,
     Submission,
     CreateSubmissionRequest,
+    ThreatType,
+    CompressionType,
 )
 
-
 __all__ = (
     "ComputeThreatListDiffRequest",
     "ComputeThreatListDiffResponse",
@@ -46,4 +47,6 @@ __all__ = (
     "RiceDeltaEncoding",
     "Submission",
     "CreateSubmissionRequest",
+    "ThreatType",
+    "CompressionType",
 )
