@@ -27,9 +27,10 @@ from .webrisk import (
     RawIndices,
     RawHashes,
     RiceDeltaEncoding,
+    ThreatType,
+    CompressionType,
 )
 
-
 __all__ = (
     "ComputeThreatListDiffRequest",
     "ComputeThreatListDiffResponse",
@@ -42,4 +43,6 @@ __all__ = (
     "RawIndices",
     "RawHashes",
     "RiceDeltaEncoding",
+    "ThreatType",
+    "CompressionType",
 )
